#!/bin/bash
#
# buildCry.sh <gcc47|e2> <opt|debug|prof>
# default is gcc47


basequal=${1}
extraqual=${2}
pkgver=v1_7
pkgdotver=v1.7

# check to see if qualifier is set
if [ -z ${basequal} ]
then
   echo "ERROR: please define the qualifier"
   echo "USAGE: buildCry.sh <gcc47|e2> <opt|debug|prof>"
   exit 1
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    local_make=Makefile.local.opt
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    local_make=Makefile.local.debug
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    local_make=Makefile.local.prof
else
   echo "ERROR: unrecognized qualifier"
   echo "USAGE: buildCry.sh <gcc47|e2> <opt|debug|prof>"
   exit 1
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
crydir=${PRODUCTS}/cry/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/cry/${pkgver}/source
export CRYHOME=${crydir}/cry_${pkgdotver}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc v4_7_1
setup gcc v4_7_1
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.7" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${crydir}
if [ ! -d ${crydir} ]
then
   echo "ERROR: failed to create ${crydir}"
   exit 1
fi

set -x

cd ${crydir}
tar xzf ${sourcedir}/cry_${pkgdotver}.tar.gz

# apply Fermi patches
patch -b -p0 < ${sourcedir}/cry_v1.7.patch

# extra instructions are in Makefile.local
cp ${sourcedir}/${local_make} ${CRYHOME}/Makefile.local
if [ "${basequal}" = "e2" ] 
then
  echo "CXXFLAGS += -std=c++11 -Wno-deprecated-declarations" >> ${CRYHOME}/Makefile.local
fi

cd ${CRYHOME}

export LD_LIBRARY_PATH=${CRYHOME}/lib

make 

set +x

if [ ! -d ${CRYHOME}/lib ]
then
   echo "ERROR: failed to create ${CRYHOME}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building cry for flavor ${flvr}"
   echo "Declaring cry ${pkgver} for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare cry ${pkgver} -r cry/${pkgver} -2 -m cry.table -q ${fullqual}
else 
   ups declare cry ${pkgver} -r cry/${pkgver} -4 -m cry.table -q ${fullqual}
fi
setup cry ${pkgver} -q ${fullqual}
echo "cry is installed at ${CRYHOME}"

set -x
# fixing embedded path
mv ${CRYHOME}/setup ${CRYHOME}/setup.bak
cat ${CRYHOME}/setup.bak | sed 's%^cd ".*$%cd ${CRYHOME}%' > ${CRYHOME}/setup

exit 0
