#!/bin/bash
#
# buildGenie.sh <gcc47|e2> <opt|debug|prof>

basequal=${1}
extraqual=${2}
pkgver=v3665c

# check to see if qualifier is set
if [ -z ${basequal} ]
then
   echo "ERROR: please define the qualifier"
   echo "USAGE: buildGenie.sh <gcc47|e2> <opt|debug|prof>"
   exit 1
fi

if [ "${basequal}" = "gcc47" ] 
then
    gccdotver=4.7
    gccver=v4_7_1
elif [ "${basequal}" = "e2" ] 
then
    gccdotver=4.7
    gccver=v4_7_1
else
   echo "ERROR: unrecognized qualifier"
   echo "USAGE: buildGenie.sh <gcc47|e2> <opt|debug|prof>"
   exit 1
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extracommand="--with-optimiz-level=O3"
    cxxflg="-g -DNDEBUG"
    # compile flags for optimiz-level=O3: g++ -c  -Wall -fPIC  -O3   -Wno-strict-aliasing -ffriend-injection
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extracommand="--enable-debug --with-optimiz-level=O0"
    #cxxflg="-g -O0"
    # compile flags for --enable-debug --with-optimiz-level=O0: g++ -c  -Wall -fPIC -g -O0   -Wno-strict-aliasing -ffriend-injection
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    # enable-profiler needs path to profiler library, but we do not build against any profiler
    #extracommand="--enable-profiler --with-profiler-lib= --with-optimiz-level=O3"
    extracommand="--with-optimiz-level=O3"
    cxxflg="-g -DNDEBUG -fno-omit-frame-pointer"
    # compile flags for optimiz-level=O3: g++ -c  -Wall -fPIC  -O3   -Wno-strict-aliasing -ffriend-injection
else
   echo "ERROR: unrecognized qualifier"
   echo "USAGE: buildGenie.sh <gcc47|e2> <opt|debug|prof>"
   exit 1
fi

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup

OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# declare now so we can setup
geniedir=${PRODUCTS}/genie/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/genie/${pkgver}/source
mkdir -p ${geniedir}
if [ ! -d ${geniedir} ]
then
   echo "ERROR: failed to create ${geniedir}"
   exit 1
fi

echo "Declaring genie ${pkgver} for ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare genie ${pkgver} -r genie/${pkgver} -2 -m genie.table -q ${fullqual}
else 
   ups declare genie ${pkgver} -r genie/${pkgver} -4 -m genie.table -q ${fullqual}
fi

# setup genie
setup genie ${pkgver} -q ${fullqual}

# check gcc
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ -z ${PYLIB} ]
then
   echo "ERROR: failed to setup pythia"
   exit 1
else
   echo "PYLIB: ${PYLIB}"
fi

if [ -z ${ROOTSYS} ]
then
   echo "ERROR: failed to setup root"
   exit 1
else
   echo "ROOTSYS: ${ROOTSYS}"
fi

if [ -z ${LIBXML2_INC} ]
then
   echo "ERROR: failed to setup libxml"
   exit 1
else
   echo "LIBXML2_INC: ${LIBXML2_INC}"
fi

if [ -z ${LOG4CPP_INC} ]
then
   echo "ERROR: failed to setup log4cpp"
   exit 1
else
   echo "LOG4CPP_INC: ${LOG4CPP_INC}"
fi

if [ -z ${LHAPDF_INC} ]
then
   echo "ERROR: failed to setup lhapdf"
   exit 1
else
   echo "LHAPDF_INC: ${LHAPDF_INC}"
fi

set -x

cd ${geniedir}
tar xf ${sourcedir}/genie-3665.tar.bz2

cd ${GENIE}

# configure generates .../src/make/Make.config
./configure  --prefix=${geniedir} ${extracommand} \
--enable-lhapdf \
--enable-rwght \
--enable-numi \
--enable-atmo \
--enable-event-server \
--enable-nucleon-decay \
--enable-vle-extension \
--with-pythia6-lib=${PYLIB} \
--with-lhapdf-lib=${LHAPDF_FQ_DIR}/lib \
--with-lhapdf-inc=${LHAPDF_INC} \
--with-libxml2-inc=${LIBXML2_INC} \
--with-libxml2-lib=${LIBXML2_FQ_DIR}/lib \
--with-log4cpp-inc=${LOG4CPP_INC} \
--with-log4cpp-lib=${LOG4CPP_FQ_DIR}/lib

# you must pass extra compiler flags directly to make
if [ "${basequal}" = "e2" ] 
then
  make GOPT_WITH_CXX_USERDEF_FLAGS="${cxxflg} -std=c++11 -Wno-deprecated-declarations"
  make install
else
  make GOPT_WITH_CXX_USERDEF_FLAGS="${cxxflg}"
  make install
fi

set +x

if [ ! -d ${GENIE}/lib ]
then
   echo "ERROR: failed to create ${geniedir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building genie for flavor ${flvr}"
setup genie ${pkgver} -q ${fullqual}
echo "genie is installed at ${GENIE}"

echo ""
echo "FIX PATHS in $GENIE/src/make/Make.config"
echo ""

exit 0
