#!/bin/bash
#

# buildLhapdf.sh <opt|debug|prof> [e2|gcc47|gcc46]
# default is gcc47

extraqual=${1}
basequal=${2}

if [ -z ${basequal} ]
then
    basequal=gcc47
fi

pkgver=v5_8_8
pkgdotver=5.8.8

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
   echo "ERROR: please specify debug, opt, or prof"
   echo "USAGE: buildLhapdf.sh <opt|debug|prof> [e2|gcc47|gcc46]"
   exit 1
fi

if [ "${basequal}" = "e2" ] ||  [ "${basequal}" = "gcc47" ]
then
   gccdotver=4.7
   gccver=v4_7_1
else
   gccdotver=4.6
   gccver=v4_6_1
fi

if [ "${basequal}" = "e2" ] 
then
  cxxflg="${cxxflg} -std=c++11 -Wno-deprecated-declarations"
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
lhapdfdir=${PRODUCTS}/lhapdf/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/lhapdf/${pkgver}/source/lhapdf-${pkgdotver}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

# we need a stupid link for libtool
if [ ! -e /tmp/build-gcc-${gccver} ]
then
   ups build_prefix gcc ${gccver}
fi

mkdir -p ${lhapdfdir}/build
if [ ! -d ${lhapdfdir}/build ]
then
   echo "ERROR: failed to create ${lhapdfdir}/build"
   exit 1
fi
cd ${lhapdfdir}/build

set -x

CXXFLAGS="${cxxflg}" ${sourcedir}/configure --prefix=${lhapdfdir} --enable-low-memory --disable-pyext
make 
# make check requires pdfsets, so skip
#make check
make install 

# install example source code by hand
cp -pr ${sourcedir}/examples ${lhapdfdir}/examples
rm -f ${lhapdfdir}/examples/Makefile.*
rm -f ${lhapdfdir}/examples/*.py
cp -p ${lhapdfdir}/build/examples/* ${lhapdfdir}/examples/

set +x

if [ ! -d ${lhapdfdir}/lib ]
then
   echo "ERROR: failed to create ${lhapdfdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# fixing bin/lhapdf-config
mv ${lhapdfdir}/bin/lhapdf-config ${lhapdfdir}/bin/lhapdf-config.bak
cat ${lhapdfdir}/bin/lhapdf-config.bak | sed 's%^prefix=.*$%prefix=${LHAPDF_FQ_DIR}%' > ${lhapdfdir}/bin/lhapdf-config


# this should not complain
   echo "Finished building lhapdf for flavor ${flvr}"
   echo "Declaring lhapdf ${pkgver} for ${flvr} and ${fullqual}"
OS=`uname`
if [ ${OS} = "Darwin" ]
then
   ups declare lhapdf ${pkgver} -r lhapdf/${pkgver} -2 -m lhapdf.table -q ${fullqual}
else 
   ups declare lhapdf ${pkgver} -r lhapdf/${pkgver} -4 -m lhapdf.table -q ${fullqual}
fi
setup lhapdf ${pkgver} -q ${fullqual}
echo "lhapdf is installed at ${LHAPDF_FQ_DIR}"

exit 0
