#!/bin/bash
#
# buildLog4cpp.sh <e2|gcc47> <opt|debug|prof>

basequal=${1}
extraqual=${2}

pkgver=v1_1
pkgdotver=1.1
gccdotver=4.7
gccver=v4_7_1

if [ -z ${basequal} ]
then
   echo "USAGE: buildLog4cpp.sh <e2|gcc47> <opt|debug|prof>"
   exit 1
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
   echo "ERROR: please specify debug, opt, or prof"
   echo "USAGE: buildLog4cpp.sh <e2|gcc47> <opt|debug|prof>"
   exit 1
fi

if [ "${basequal}" = "e2" ] 
then
  cxxflg="-std=c++11 -Wno-deprecated-declarations ${cflg}"
else
  cxxflg="${cflg}"

fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

log4cppdir=${PRODUCTS}/log4cpp/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/log4cpp/${pkgver}/source

mkdir -p ${log4cppdir}/build
if [ ! -d ${log4cppdir}/build ]
then
   echo "ERROR: failed to create ${log4cppdir}/build"
   exit 1
fi

cd ${log4cppdir}/build

set -x

CXXFLAGS="${cxxflg}" CFLAGS="${cflg}" ${sourcedir}/log4cpp-${pkgdotver}/configure --prefix=${log4cppdir}
make 
make check
make install 

set +x

if [ ! -d ${log4cppdir}/lib ]
then
   echo "ERROR: failed to create ${log4cppdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# fixing bin/log4cpp-config
#mv ${log4cppdir}/bin/log4cpp-config ${log4cppdir}/bin/log4cpp-config.bak
#cat ${log4cppdir}/bin/log4cpp-config.bak | sed 's%${log4cppdir}%${LOG4CPP_FQ_DIR}%' > ${log4cppdir}/bin/log4cpp-config


# this should not complain
echo "Declaring log4cpp ${pkgver} for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare log4cpp ${pkgver} -r log4cpp/${pkgver} -2 -m log4cpp.table -q ${fullqual}
else 
   ups declare log4cpp ${pkgver} -r log4cpp/${pkgver} -4 -m log4cpp.table -q ${fullqual}
fi
setup log4cpp ${pkgver} -q ${fullqual}
echo "log4cpp is installed at ${LOG4CPP_FQ_DIR}"

echo " "
echo "Please edit ${log4cppdir}/bin/log4cpp-config,"
echo "replacing ${log4cppdir} with \${LOG4CPP_FQ_DIR}"

exit 0
