#!/bin/bash
#
# buildMysql.sh [gcc47|e2]
# default is gcc47

basequal=${1}

if [ -z ${basequal} ]
then
    basequal=gcc47
fi
gccdotver=4.7
gccver=v4_7_1

pkgver=v5_5_27
pkgdotver=5.5.27

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

mydir=${PRODUCTS}/mysql_client/${pkgver}/${flvr}-${basequal}
sourcedir=${PRODUCTS}/mysql_client/${pkgver}/source

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup cmake
setup cmake

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${mydir}/build
if [ ! -d ${mydir}/build ]
then
   echo "ERROR: failed to create ${mydir}/build"
   exit 1
fi

##CFLAGS="-O3" CXX=gcc CXXFLAGS="-O3 -felide-constructors \
 ##      -fno-exceptions -fno-rtti" ${sourcedir}/configure \
##       --prefix=${mydir} --without-server --with-mysqld-ldflags=-all-static
##

set -x

cd ${mydir}/build

if [ ${basequal} = "e2" ]
then
    cmake -DCMAKE_INSTALL_PREFIX=${mydir} -DCMAKE_CXX_FLAGS="-std=c++11 -Wno-deprecated-declarations" -DWITHOUT_SERVER:BOOL=ON ${sourcedir}/mysql-${pkgdotver}
else
    cmake -DCMAKE_INSTALL_PREFIX=${mydir} -DWITHOUT_SERVER:BOOL=ON ${sourcedir}/mysql-${pkgdotver}
fi
make
make install

set +x

if [ ! -d ${mydir}/lib ]
then
   echo "ERROR: failed to create ${mydir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

if [ ! -d ${mydir}/bin ]
then
   echo "ERROR: failed to create ${mydir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building mysql_client for flavor ${flvr}"
echo "Declaring mysql_client ${pkgver} for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare mysql_client ${pkgver} -r mysql_client/${pkgver} -2 -m mysql_client.table -q ${basequal}
else 
   ups declare mysql_client ${pkgver} -r mysql_client/${pkgver} -4 -m mysql_client.table -q ${basequal}
fi
setup mysql_client ${pkgver} -q ${basequal}
echo "mysql_client is installed at ${MYSQL_CLIENT_DIR}"

exit 0

