#!/bin/bash
#

# buildPandora.sh <e2|nu:e2> <debug|opt|prof> [tar] [source]

usage()
{
   echo "USAGE: buildPandora.sh <e2|nu:e2> <debug|opt|prof> [tar]"
}

make_tarball()
{
    echo ""
    echo "OK - building tarball for ${package} ${pkgver} ${flvr} ${qual}"
    set -x
    cd ${PRODUCTS}
    tarname=${package}-${pkgdotver}-${OS}-${plat}-${qualdir}.tar.bz2
    tar cjf ${tarname} \
       ${package}/${pkgver}.version/${flvr}_${qualver} \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/${flvr}-${qualdir}
    cd ${thisdir}
    set +x
    exit 0
}

make_source_tarball()
{
    set -x
    cd ${PRODUCTS}
    tar cjf ${package}-${pkgdotver}-source.tar.bz2 \
       ${package}/${pkgver}/*.sh \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source
    cd ${thisdir}
    set +x
}

basequal=${1}
extraqual=${2}
maketar=${3}
sourcetar=${4}

package=pandora
pkgver=v00_11a
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
thisdir=`pwd`

if [ -z ${PRODUCTS} ]
then
    echo "ERROR: ups is not setup"
    exit 1
fi

if [ "${sourcetar}" = "source" ]
then
  make_source_tarball
fi

if [ -z ${basequal} ]
then
    echo "ERROR: please specify the base qualifier"
    usage
    exit 1
fi

xqual=`echo ${basequal} | sed -e s%:%-%g`
gccdotver=4.7
gccver=v4_7_1

if [ "${basequal}" = "e2" ]
then
   vqual=${basequal}
elif [ "${basequal}" = "nu:e2" ]
then
   vqual=e2_nu
elif [ "${basequal}" = "e2:nu" ]
then
   vqual=e2_nu
else
   echo "ERROR: unrecognized base qualifier"
   usage
   exit 1
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${xqual}-${extraqual}
    qualver=${vqual}_${extraqual}
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${xqual}-${extraqual}
    qualver=${extraqual}_${vqual}
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${xqual}-${extraqual}
    qualver=${vqual}_${extraqual}
else
   echo "ERROR: please define the extra qualifier"
   usage
   exit 1
fi

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup

OS1=`uname`
if [ ${OS1} = "Darwin" ]
then
    flvr=`ups flavor -2`
    plat=`uname -m`
    OSnum=`uname -r | cut -f1 -d"."`
    macos=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1,2`
    macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1`
    macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 2`
    #OS=${OS1}${OSnum}
    OS=mac${macos1}${macos2}
else
    flvr=`ups flavor`
    plat=`uname -p`
    OSnum=`lsb_release -r | cut -f2 | cut -f1 -d"."`
    OS=${OS1}${OSnum}
    if [ `lsb_release -d | cut  -f3 -d" "` = "SLF" ]
    then
       OS=slf${OSnum}
    fi
   if [ `lsb_release -i | cut -f2` = "ScientificFermi" ]
   then
      OS=slf${OSnum}
   fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "SLC" ]
    then
       OS=slc${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "LTS" ]
    then
       OS=slf${OSnum}
    fi
fi

pkgdir=${PRODUCTS}/${package}/${pkgver}/${flvr}-${qualdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   make_tarball
fi

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

echo "Declaring pandora ${pkgver} for flavor ${flvr}"
if [ ${OS1} = "Darwin" ]
then
   ups declare pandora ${pkgver} -r pandora/${pkgver} -2 -m pandora.table -q ${fullqual}
else 
   ups declare pandora ${pkgver} -r pandora/${pkgver} -4 -m pandora.table -q ${fullqual}
fi

set -x

ups build pandora ${pkgver} -q ${fullqual}

set +x

# this should not complain
setup pandora ${pkgver} -q ${fullqual}

if [ ! -d ${PANDORA_FQ_DIR}/lib ]
then
   echo "ERROR: build failed to create ${PANDORA_FQ_DIR}/lib"
   echo "       Something is very wrong"
   exit 1
fi
echo "pandora is installed at ${PANDORA_FQ_DIR}"

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   make_tarball
fi

exit 0
