#!/bin/bash
#
# buildPostgres.sh [gcc46|gcc47]
# default is gcc47

# code is all C, so e2 is not needed

qual=${1}

if [ -z ${qual} ]
then
    qual=gcc47
fi

# check to see if qualifier is set
if [ "${qual}" = "gcc47" ]
then
   gccdotver=4.7
   gccver=v4_7_1
elif [ "${qual}" = "gcc46" ]
then
   gccdotver=4.6
   gccver=v4_6_1
else
  echo "USAGE: buildPostgres.sh [gcc46|gcc47]"
  exit 1
fi
echo "OK: building for ${qual}"

pkgver=v9_1_5
pkgdotver=9.1.5


source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

pgdir=${PRODUCTS}/postgresql/${pkgver}/${flvr}-${qual}
mkdir -p ${pgdir}/build
if [ ! -d ${pgdir}/build ]
then
   echo "ERROR: failed to create ${pgdir}/build"
   exit 1
fi

# declare and setup postgresql
if [ ${OS} = "Darwin" ]
then
   ups declare postgresql ${pkgver} -r postgresql/${pkgver} -2 -m postgresql.table -q ${qual}
else 
   ups declare postgresql ${pkgver} -r postgresql/${pkgver} -4 -m postgresql.table -q ${qual}
fi

setup postgresql ${pkgver} -q ${qual}

# check gcc
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

if [ -z ${PYTHONHOME} ]
then
   echo "ERROR: PYTHONHOME is undefined"
   echo "       something is very wrong"
   exit 1
else 
   ls ${PYTHONHOME}/lib
fi

cd ${pgdir}/build

set -x

${pgdir}/../source/postgresql-${pkgdotver}/configure \
        --prefix=${pgdir} \
	--with-krb5 \
	--with-gssapi \
	--with-python
make
#make install

# install only the client: 
make -C src/bin install
make -C src/include install
make -C src/interfaces install
make -C doc install

set +x

if [ ! -d ${pgdir}/lib ]
then
   echo "ERROR: failed to create ${pgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building postgresql for ${flvr} and ${qual}"
setup postgresql ${pkgver} -q ${qual}
echo "postgresql is installed at ${PGSQL_DIR}"

exit 0
