#!/bin/bash
#
# buildPythia.sh <opt|debug|prof> [gcc47]
# default is gcc47

extraqual=${1}
basequal=${2}
pkgver=v6_4_26

if [ -z ${basequal} ]
then
    basequal=gcc47
fi
gccdotver=4.7
gccver=v4_7_1

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG"
    extra_command="-DCMAKE_BUILD_TYPE=Release"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-g -O0"
    extra_command="-DCMAKE_BUILD_TYPE=Debug"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
    extra_command="-DCMAKE_BUILD_TYPE=MinSizeRel"
else
   echo "ERROR: please specify debug, opt, or prof"
   echo "USAGE: buildPythia.sh <opt|debug|prof> [gcc47]"
   exit 1
fi

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
pkgdir=${PRODUCTS}/pythia/${pkgver}/${flvr}-${qualdir}
srcdir=${PRODUCTS}/pythia/${pkgver}/source/pythia

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc and cmake
setup cmake
# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${pkgdir}/build
if [ ! -d ${pkgdir}/build ]
then
   echo "ERROR: failed to create ${pkgdir}/build"
   exit 1
fi

set -x

cd ${pkgdir}/build
cmake -DCMAKE_INSTALL_PREFIX=${pkgdir} ${extra_command} ${srcdir}
make -j4
make test
make install 

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building pythia for flavor ${flvr}"
   echo "Declaring pythia ${pkgver} for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare pythia ${pkgver} -r pythia/${pkgver} -2 -m pythia.table -q ${fullqual}
else 
   ups declare pythia ${pkgver} -r pythia/${pkgver} -4 -m pythia.table -q ${fullqual}
fi
setup pythia ${pkgver} -q ${fullqual}
echo "pythia is installed at ${PYTHIA_FQ_DIR}"

exit 0
